@@ -73,9 +73,8 @@ class CloudStackProvider(object):
                     if 'jobid' in response:
                         LOG.warning("VirtualMachine destroyed!")
 
-                        #removing data from flipper
                         flipper = FlipperProvider()
-                        flipper.destroy_flipper_dependencies(name= database.databaseinfra.name[:20], environment= environment)
+                        flipper.destroy_flipper_dependencies(masterpairname=database.databaseinfra.name, environment=environment)
 
                         instance = Instance.objects.get(hostname=host)
                         
@@ -191,42 +190,23 @@ class CloudStackProvider(object):
         #response = api.listVirtualMachines('GET',request)
         #print response
         
-        databaseinfra = DatabaseInfra()
-        databaseinfra.name = infraname
-        databaseinfra.user  = 'root'
-        databaseinfra.password = 'root'
-        databaseinfra.engine = plan.engine_type.engines.all()[0]
-        databaseinfra.plan = plan
-        databaseinfra.environment = environment
-        databaseinfra.capacity = 1
-        databaseinfra.per_database_size_mbytes=0
-        databaseinfra.save()
-        LOG.info("DatabaseInfra created!")
+        databaseinfra = self.build_databaseinfra(infraname= infraname, plan= plan, environment= environment)
 
         instances = []
-        x = 0 
 
         for vmname in names["vms"]:
-            instances.append(self.create_vm(api, planattr, project_id, infraname, vmname, plan, environment, True, databaseinfra))
+            instance = self.create_vm(api, planattr, project_id, infraname, vmname, plan, environment, True, databaseinfra)
+
+            if instance==None:
+                for i in instances:
+
+                    LOG.warning("Destroying cloudstack cluster instance!")
+                    self.destroy_vm(environment= environment, instance=i)
 
-            if x == 0 and instances[0]==None:
                 databaseinfra.delete()
                 return None
-
-            if x ==1 and instances[1]==None:
-                LOG.warning("Destroying cloudstack cluster instance!")
-            
-                project_id = self.get_credentials(environment= environment).project
-
-                api = self.auth(environment= environment)
-                request = { 'projectid': '%s' % (project_id),
-                            'id': '%s' % (instances[0].hostname.cs_host_attributes.all()[0].vm_id)
-                          }
-                api.destroyVirtualMachine('GET',request)
-                databaseinfra.delete()
-                return None
-
-            x+=1
+            else:
+                instances.append(instance)
 
         databasesinfraattr = DatabaseInfraAttr.objects.filter(databaseinfra=databaseinfra)
         infraattr0 = databasesinfraattr[0]
@@ -239,7 +219,7 @@ class CloudStackProvider(object):
             'IPMASTER': None,
             'IPWRITE': databasesinfraattr[0].ip,
             'IPREAD': databasesinfraattr[1].ip,
-            'MASTERPAIRNAME': name[0:20],
+            'MASTERPAIRNAME': infraname,
             'HOST01': instances[0].hostname,
             'HOST02': instances[1].hostname,
             'INSTANCE01': instances[0],
@@ -253,9 +233,6 @@ class CloudStackProvider(object):
 
             self.build_dependencies(contextdict=contextdict, host=contextdict['HOST02'], serverid=2, master=contextdict['HOST01'], 
                                          environment=environment, plan=plan, databaseinfra=databaseinfra, api=api)
-
-            #self.run_script(contextdict['HOST01'], contextdict['SECOND_SCRIPT_FILE'])
-            #self.run_script(contextdict['HOST02'], contextdict['SECOND_SCRIPT_FILE'])
             
             if self.run_script(contextdict['HOST01'], contextdict['SECOND_SCRIPT_FILE'])==0:
                 if self.run_script(contextdict['HOST02'], contextdict['SECOND_SCRIPT_FILE'])==0:
@@ -275,12 +252,21 @@ class CloudStackProvider(object):
                 api.destroyVirtualMachine('POST',{'id': "%s" % (instance.hostname.cs_host_attributes.all()[0].vm_id)})
                 instance.hostname.delete()            
                 flipper = FlipperProvider()
-                flipper.destroy_flipper_dependencies(name= databaseinfra.name[:20], environment= environment)
+                flipper.destroy_flipper_dependencies(masterpairname= databaseinfra.name, environment= environment)
             databaseinfra.delete()
             return None
         
         return databaseinfra
 
+    @classmethod
+    def destroy_vm(self, environment, instance):
+        project_id = self.get_credentials(environment= environment).project
+
+        api = self.auth(environment= environment)
+        request = { 'projectid': '%s' % (project_id),
+                              'id': '%s' % (instance.hostname.cs_host_attributes.all()[0].vm_id)
+                            }
+        api.destroyVirtualMachine('GET',request)
 
 
     @classmethod
@@ -367,6 +353,17 @@ class CloudStackProvider(object):
         if instance is None:
             return None
         
+        databaseinfra =  self.build_databaseinfra(infraname= infraname, plan= plan, environment= environment)
+        databaseinfra.endpoint = instance.address + ":%i" %(instance.port)
+        databaseinfra.save()
+        instance.databaseinfra = databaseinfra
+        instance.save()
+        LOG.info("Instance created!")
+        
+        return databaseinfra
+
+    @classmethod
+    def build_databaseinfra(self, infraname, plan, environment):
         databaseinfra = DatabaseInfra()
         databaseinfra.name = infraname
         databaseinfra.user  = 'root'
@@ -376,14 +373,8 @@ class CloudStackProvider(object):
         databaseinfra.environment = environment
         databaseinfra.capacity = 1
         databaseinfra.per_database_size_mbytes=0
-        databaseinfra.endpoint = instance.address + ":%i" %(instance.port)
         databaseinfra.save()
         LOG.info("DatabaseInfra created!")
-        
-        instance.databaseinfra = databaseinfra
-        instance.save()
-        LOG.info("Instance created!")
-        
         return databaseinfra
 
     @classmethod
